#!/bin/sh

# RHEL 7 update shell script

WAR_FILE="netvizura.war"

if [[ ! -e /var/log/netvizura ]]; then
	mkdir /var/log/netvizura
elif [[ ! -d /var/log/netvizura ]]; then
	echo "/var/log/netvizura already exists but is not a directory" 1>&2
fi

tomcat_svc=$(systemctl list-units --no-pager --all | grep -Eo "tomcat[^[:space:]]+" | xargs)

echo "Stoping Tomcat service"
systemctl stop $tomcat_svc

sed --in-place=.bak "s/ docBase=.*\"//" /etc/tomcat/Catalina/localhost/netvizura.xml

NETVIZURA_DIR="/usr/share/tomcat/webapps/netvizura"

cp ${WAR_FILE} "${NETVIZURA_DIR}.war"

if [ -e $NETVIZURA_DIR ]
then
	rm -rf $NETVIZURA_DIR
fi

echo "Applying database patches"
cd ./sql
bash ./patch.sh
cd ..

## FIREWALL CONFIG START

echo "Configuring firewall"
systemctl start firewalld

## open sFLow port if not already open

SFLOW_PORT=6343

firewall-cmd --zone=public --query-port=$SFLOW_PORT/udp | grep yes > /dev/null 2>&1

if [ $? -eq 1 ]; then
        echo "Opening port ${SFLOW_PORT} for sFlow collection"
        firewall-cmd --zone=public --add-port=$SFLOW_PORT/udp --permanent
        echo "Reloading firewall"
        firewall-cmd --reload
else
        echo "sFlow port ${SFLOW_PORT} is open"
fi

## FIREWALL CONFIG END

echo "Starting Tomcat service"

systemctl start $tomcat_svc
